#
# spec file for package python-svgpathtools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global skip_python36 1
Name:           python-svgpathtools
Version:        1.6.1
Release:        1.8
Summary:        Tools for manipulating and analyzing SVG Path objects and Bézier curves
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/mathandy/svgpathtools
Source:         https://files.pythonhosted.org/packages/source/s/svgpathtools/svgpathtools-%{version}.tar.gz
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module svgwrite}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires:       python-scipy
Requires:       python-svgwrite
BuildArch:      noarch
%python_subpackages

%description
Svgpathtools is a collection of tools for manipulating and
analyzing SVG Path objects and Bézier curves.

%prep
%setup -q -n svgpathtools-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# test suite uses hashes that only match on some CPUs
# due to float math
# https://github.com/mathandy/svgpathtools/issues/183
# %%check
# %%pytest

%files %{python_files}
%license LICENSE.txt LICENSE2.txt
%doc README.md
%{python_sitelib}/svgpathtools*

%changelog
* Sun May 21 2023 Mia Herkt <mia@0x0.st>
- Update to 1.6.1
  * Fix circles parsing to non-closed paths
    [#]gh/mathandy/svgpathtools#198
  * path.transform: Arc sweep is reversed by negative scale
    [#]gh/mathandy/svgpathtools#200
  * return error if Path.point() cannot be computed
* Tue Feb 21 2023 Mia Herkt <mia@0x0.st>
- Updote to 1.6.0
* Wed Jul 20 2022 Mia Herkt <mia@0x0.st>
- Update to 1.5.1
  * Fix float rounding error in elliptic arc radius check
    (#gh/mathandy/svgpathtools#171)
- Disable test suite because it can only work on specific CPU
  (micro-)architectures.
  (#gh/mathandy/svgpathtools#183)
* Wed Jun 15 2022 Mia Herkt <mia@0x0.st>
- Update to 1.5.0
  * Fix implementation of points()
    (#gh/mathandy/svgpathtools#155)
  * Add support for rounded rectangles
    (#gh/mathandy/svgpathtools#161)
  * Fix Document.add_path for empty groups
    (#gh/mathandy/svgpathtools#170)
  * Allow file-like object as input to Documents ctor and
    svg2paths function
  * Add convenience functions for converting svgs contained in a
    string to paths
* Thu Dec 23 2021 Mia Herkt <mia@0x0.st>
- Update to 1.4.4
  * Fix issue with filenames with no directory causing error
- No notable changes in 1.4.3
- Changes in 1.4.2:
  * Hashable Path objects, and more.
* Sat Feb 13 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 (scipy)
* Wed Dec 16 2020 Mia Herkt <mia@0x0.st>
- Update to 1.4.1
  * Added clipping to work around floating point error in
    Arc._parameterize
  * Support flattening SVG groups and handling transforms
  * save() now requires filename
  * Better implementation of Arc.intersect(Line)
  * Fixed issue with viewbox being written as tuple
  * Added paths2Drawing functionality
  * Update Path.area to work with Arc segments
  * When cx and cy attributes are not defined either in ellipse
    or circle tag, consider both to be 0
  * Fix Arc.sweep when transform scale flips it around
  * Relative path support
  * Fixed crash in line2paths()
  * Support flattening paths of only nested groups
  * Add Path.is_contained_by() to check if one path is inside
    another
  * Fix Arc/Arch intersections
  * Add Path.attributes and Path.meta attributes
  * Fix polyline and polygon conversion
  * Document now stores element and transform in path
  * Renamed Document.flatten_all_paths to flattened_paths
  * Added vectorized points() method for bezier segments
  * Sped up randialrange for Line objects
  * Fix paths-data-12-t.svg from the SVG 1.1 test suite
* Thu Jul 23 2020 Mia Herkt <mia@0x0.st>
- init, 1.3.3
